============================
Deployment and bootstrapping
============================

This section describes deployment and provisioning of baremetal control plane
hosts.

.. toctree::
   :maxdepth: 1

   bifrost
   bootstrap-servers
